@@ -1,3 +1,4 @@
+import os
 import sys
 import time
 
@@ -99,3 +100,10 @@ def initParDict():
 
 def isDev():
     return sys.executable.endswith("python.exe")
+
+
+def create():
+    currentFolder = os.path.dirname(__file__)
+    file = b.getPath(currentFolder, "data/task.zip")
+    print(file)
+    print(os.path.exists(file))
